package com.chelvc.cloud.vehicle.api.param;
import com.chelvc.cloud.vehicle.api.constant.CouponStatus;
import com.chelvc.cloud.vehicle.api.constant.CouponType;
import lombok.*;
import lombok.experimental.SuperBuilder;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.Date;

/**
 * 优惠券数据模型
 *
 * @author liude
 * @date 2023/8/27
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@ToString(callSuper = true)
public class CouponModifyParam {

    /**
     * 商家ID
     */
    @NotNull(message = "商家ID不能为空")
    private Long merchantId;

    /**
     * 优惠券类型
     */
    @NotNull(message = "优惠券类型不能为空")
    private CouponType type;

    /**
     * 优惠券名称
     */
    @NotEmpty(message = "优惠券名称不能为空")
    @Size(max = 100, message = "优惠券名称长度不能大于100")
    private String name;

    /**
     * 优惠金额
     */
    @NotNull(message = "优惠金额不能为空")
    private Double amount;

    /**
     * 满减金额
     */
    @NotNull(message = "满减金额不能为空")
    private Double reduce;

    /**
     * 优惠折扣
     */
    @NotNull(message = "优惠折扣不能为空")
    private Double discount;

    /**
     * 过期时间
     */
    private Date expiration;

    /**
     * 优惠券描述
     */
    @NotEmpty(message = "优惠券描述不能为空")
    @Size(max = 100, message = "优惠券描述长度不能大于100")
    private String description;

    /**
     * 优惠券状态
     */
    @NotNull(message = "优惠券状态不能为空")
    private CouponStatus status;
}
