package com.chelvc.cloud.vehicle.api.param;
import com.chelvc.cloud.vehicle.api.constant.CategoryType;
import com.chelvc.cloud.vehicle.api.constant.GoodsStatus;
import com.chelvc.framework.common.model.File;
import lombok.*;
import lombok.experimental.SuperBuilder;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.List;

/**
 * 商品数据模型
 *
 * @author liude
 * @date 2023/8/30
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@ToString(callSuper = true)
public class GoodsModifyParam {

    /**
     * 分类类型
     */
    @NotNull(message = "分类类型不能为空")
    private CategoryType type;

    /**
     * 分类ID
     */
    @NotNull(message = "分类ID不能为空")
    private Long categoryId;

    /**
     * 商家ID
     */
    @NotNull(message = "商家ID不能为空")
    private Long merchantId;

    /**
     * 商品名称
     */
    @NotEmpty(message = "商品名称不能为空")
    @Size(max = 100, message = "商品名称长度不能大于100")
    private String name;

    /**
     * 商品Logo
     */
    @Size(max = 200, message = "商品Logo长度不能大于200")
    private String logo;

    /**
     * 轮播图列表
     */
    private List<File> banners;

    /**
     * 商品描述
     */
    @NotEmpty(message = "商品描述不能为空")
    @Size(max = 100, message = "商品描述长度不能大于500")
    private String description;

    /**
     * 商品原价
     */
    @NotNull(message = "商品原价不能为空")
    private Double originalPrice;

    /**
     * 优惠价格
     */
    @NotNull(message = "优惠价格不能为空")
    private Double specialPrice;
    //

    /**
     * 优惠券ID列表
     */
    private List<Long> couponIds;

    /**
     * 商品状态
     */
    @NotNull(message = "商品状态不能为空")
    private GoodsStatus status;
}
