package com.chelvc.cloud.vehicle.api.param;

import java.io.Serializable;
import java.util.List;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import com.chelvc.framework.common.model.File;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 商家数据模型
 *
 * @author xp
 * @data 2023/4/10
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class MerchantModifyParam implements Serializable {
    /**
     * 商家名称
     */
    @NotEmpty(message = "商家名称不能为空")
    @Size(max = 100, message = "商家名称长度不能大于100")
    private String name;

    /**
     * 商家Logo
     */
    @Size(max = 200, message = "商家Logo长度不能大于200")
    private String logo;

    /**
     * 轮播图列表
     */
    private List<File> banners;

    /**
     * 联系人
     */
    @NotEmpty(message = "联系人不能为空")
    @Size(max = 50, message = "联系人长度不能大于50")
    private String liaison;

    /**
     * 联系电话
     */
    @NotEmpty(message = "联系电话不能为空")
    @Size(max = 50, message = "联系电话长度不能大于50")
    private String mobile;

    /**
     * 营业时间
     */
    @NotEmpty(message = "营业时间不能为空")
    @Size(max = 50, message = "营业时间长度不能大于50")
    private String opening;

    /**
     * 详细地址
     */
    @NotEmpty(message = "详细地址不能为空")
    @Size(max = 200, message = "营业时间长度不能大于200")
    private String address;

    /**
     * 所属地区
     */
    @NotNull(message = "所属地区不能为空")
    @Min(value = 100000, message = "所属地区不能小于100000")
    @Max(value = 999999, message = "所属地区不能大于999999")
    private Integer region;

    /**
     * 经度
     */
    @NotNull(message = "经度不能为空")
    private Double longitude;

    /**
     * 纬度
     */
    @NotNull(message = "纬度不能为空")
    private Double latitude;

    /**
     * 是否推荐
     */
    @NotNull(message = "是否推荐不能为空")
    private Boolean recommend;
}
