package com.chelvc.cloud.vehicle.api.param;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import com.chelvc.cloud.vehicle.api.constant.Sort;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.ToString;
import lombok.experimental.SuperBuilder;

/**
 * 商家查询参数
 *
 * @author Woody
 * @date 2023/7/20
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class MerchantQueryParam extends LocationQueryParam {
    /**
     * 关键字
     */
    @Size(max = 50, message = "关键字长度不能大于50")
    private String keyword;

    /**
     * 分类ID
     */
    @Min(value = 1, message = "分类ID不能小于1")
    private Long categoryId;

    /**
     * 偏移商家ID
     */
    @Min(value = 1, message = "偏移商家ID不能小于1")
    private Long offset;

    /**
     * 排序规则
     */
    @NotNull(message = "排序规则不能为空")
    private Sort sort;

    /**
     * 查询数量
     */
    @NotNull(message = "查询数量不能为空")
    @Min(value = 1, message = "查询数量不能小于1")
    @Max(value = 20, message = "查询数量不能大于20")
    private Integer size;
}
