package com.chelvc.cloud.vehicle.api.service;

import java.util.List;

import com.chelvc.cloud.vehicle.api.dto.CategoryDTO;
import com.chelvc.cloud.vehicle.api.param.CategoryModifyParam;
import com.chelvc.cloud.vehicle.api.param.CategoryPagingParam;
import com.chelvc.framework.common.model.Pagination;

/**
 * 分类业务操作接口
 *
 * @author Woody
 * @date 2023/5/2
 */
public interface CategoryService {
    /**
     * 新增分类
     *
     * @param param 新增参数
     * @return 分类主键
     */
    Long addCategory(CategoryModifyParam param);

    /**
     * 修改分类
     *
     * @param id    分类主键
     * @param param 修改参数
     */
    void updateCategory(Long id, CategoryModifyParam param);

    /**
     * 查询分类
     *
     * @param param 查询参数
     * @return 分类分页信息
     */
    Pagination<CategoryDTO> getCategoryPaging(CategoryPagingParam param);

    /**
     * 获取有效分类信息
     *
     * @return 分类信息列表
     */
    List<CategoryDTO> listActiveCategories();

    /**
     * 获取推荐分类信息
     *
     * @param size 分类个数
     * @return 分类信息列表
     */
    List<CategoryDTO> listRecommendCategories(int size);


    /**
     * 删除分类
     *
     * @param id    分类主键
     */
    void deleteCategory(Long id);
}
