package com.chelvc.cloud.vehicle.api.service;

import java.util.List;

import com.chelvc.cloud.vehicle.api.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.api.dto.MerchantDetailDTO;
import com.chelvc.cloud.vehicle.api.param.LocationQueryParam;
import com.chelvc.cloud.vehicle.api.param.MerchantModifyParam;
import com.chelvc.cloud.vehicle.api.param.MerchantPagingParam;
import com.chelvc.cloud.vehicle.api.param.MerchantQueryParam;
import com.chelvc.framework.common.model.Pagination;

/**
 * 商家业务接口
 *
 * @author Woody
 * @date 2023/5/4
 */
public interface MerchantService {
    /**
     * 获取附近商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    List<MerchantDTO> listNearbyMerchants(LocationQueryParam param, int size);

    /**
     * 获取推荐商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    List<MerchantDTO> listRecommendMerchants(LocationQueryParam param, int size);

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家信息列表
     */
    List<MerchantDTO> listSimpleMerchants(MerchantQueryParam param);

    /**
     * 获取商家详情
     *
     * @param id 商家ID
     * @return 商家详情
     */
    MerchantDetailDTO getMerchantDetail(Long id);

    /**
     * 获取商家详情
     *
     * @param id 商家ID
     * @param param 查询参数
     * @return 商家详情
     */
    MerchantDetailDTO getMerchantDetail(Long id, LocationQueryParam param);

    /**
     * 新增商家
     *
     * @param param 新增参数
     * @return 商家主键
     */
    Long addMerchant(MerchantModifyParam param);

    /**
     * 修改商家
     *
     * @param id    分类主键
     * @param param 修改参数
     */
    void updateMerchant(Long id, MerchantModifyParam param);

    /**
     * 删除商家
     *
     * @param id    分类主键
     */
    void deleteMerchant(Long id);

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家分页信息
     */
    Pagination<MerchantDTO> getMerchantPaging(MerchantPagingParam param);
}
