package com.chelvc.cloud.vehicle.server.copier;

import com.chelvc.cloud.vehicle.api.dto.CouponDTO;
import com.chelvc.cloud.vehicle.api.param.CouponModifyParam;
import com.chelvc.cloud.vehicle.server.entity.Coupon;
import org.mapstruct.Builder;
import org.mapstruct.Mapper;
import org.mapstruct.MappingTarget;
import org.mapstruct.factory.Mappers;

import java.util.Collection;
import java.util.List;

/**
 * 商品优惠券拷贝接口
 *
 * @author liude
 * @date 2023/8/30
 */
@Mapper(builder = @Builder(disableBuilder = true))
public interface CouponCopier {
    /**
     * 对象拷贝接口实例
     */
    CouponCopier INSTANCE = Mappers.getMapper(CouponCopier.class);

    /**
     * 商品优惠券拷贝
     *
     * @param coupon 商品优惠券
     * @return 商品优惠券
     */
    CouponDTO copying(Coupon coupon);

    /**
     * 商品优惠券信息拷贝
     *
     * @param coupons 商品优惠券信息集合
     * @return 商品优惠券信息列表
     */
    List<CouponDTO> copying(Collection<Coupon> coupons);

    /**
     * 商品优惠券信息拷贝
     *
     * @param param 商品优惠券更新参数
     * @return 商品优惠券信息
     */
    Coupon copying(CouponModifyParam param);

    /**
     * 商品优惠券信息拷贝
     *
     * @param param    商品优惠券更新参数
     * @param  coupon 商品优惠券信息
     */
    void copying( CouponModifyParam param, @MappingTarget  Coupon coupon);
}
