package com.chelvc.cloud.vehicle.server.copier;

import com.chelvc.cloud.vehicle.api.dto.CouponDTO;
import com.chelvc.cloud.vehicle.api.dto.GoodsDTO;
import com.chelvc.cloud.vehicle.api.param.CouponModifyParam;
import com.chelvc.cloud.vehicle.api.param.GoodsModifyParam;
import com.chelvc.cloud.vehicle.server.entity.Coupon;
import com.chelvc.cloud.vehicle.server.entity.Goods;
import org.mapstruct.Builder;
import org.mapstruct.Mapper;
import org.mapstruct.MappingTarget;
import org.mapstruct.factory.Mappers;

import java.util.Collection;
import java.util.List;

/**
 * 商品信息拷贝接口
 *
 * @author Woody
 * @date 2023/8/6
 */
@Mapper(builder = @Builder(disableBuilder = true))
public interface GoodsCopier {
    /**
     * 对象拷贝接口实例
     */
    GoodsCopier INSTANCE = Mappers.getMapper(GoodsCopier.class);

    /**
     * 商品信息拷贝
     *
     * @param goods 商品详情
     * @return 商品信息
     */
    GoodsDTO copying(Goods goods);


    /**
     * 商品信息拷贝
     *
     * @param goods 商品信息集合
     * @return 商品信息列表
     */
    List<GoodsDTO> copying(Collection<Goods> goods);

    /**
     * 商品信息拷贝
     *
     * @param param 商品更新参数
     * @return 商品信息
     */
    Goods copying(GoodsModifyParam param);

    /**
     * 商品信息拷贝
     *
     * @param param    商品更新参数
     * @param  goods 商品信息
     */
    void copying( GoodsModifyParam param, @MappingTarget Goods goods);
}
