package com.chelvc.cloud.vehicle.server.entity;

import java.util.List;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.chelvc.cloud.vehicle.api.constant.CategoryType;
import com.chelvc.cloud.vehicle.api.constant.GoodsStatus;
import com.chelvc.framework.common.model.File;
import com.chelvc.framework.database.entity.ModifyEntity;
import com.chelvc.framework.database.interceptor.FilesTypeHandler;
import com.chelvc.framework.database.interceptor.LongsTypeHandler;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.ToString;
import lombok.experimental.SuperBuilder;

/**
 * 商品数据模型
 *
 * @author Woody
 * @date 2023/7/17
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
@TableName(autoResultMap = true)
public class Goods extends ModifyEntity<Long> {
    /**
     * 主键
     */
    @TableId(type = IdType.ASSIGN_ID)
    private Long id;

    /**
     * 分类类型
     */
    private CategoryType type;

    /**
     * 分类ID
     */
    private Long categoryId;

    /**
     * 商家ID
     */
    private Long merchantId;

    /**
     * 商品名称
     */
    private String name;

    /**
     * 商品Logo
     */
    private String logo;

    /**
     * 轮播图列表
     */
    @TableField(typeHandler = FilesTypeHandler.class)
    private List<File> banners;

    /**
     * 商品描述
     */
    private String description;

    /**
     * 商品原价
     */
    private Double originalPrice;

    /**
     * 优惠价格
     */
    private Double specialPrice;

    /**
     * 商品评分
     */
    private Double score;

    /**
     * 订单销量
     */
    private Integer sale;

    /**
     * 优惠券ID列表
     */
    @TableField(typeHandler = LongsTypeHandler.class)
    private List<Long> couponIds;

    /**
     * 商品状态
     */
    private GoodsStatus status;
}
