package com.chelvc.cloud.vehicle.server.entity;

import java.util.List;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.chelvc.cloud.vehicle.api.constant.MerchantStatus;
import com.chelvc.framework.common.model.File;
import com.chelvc.framework.database.entity.ModifyEntity;
import com.chelvc.framework.database.interceptor.FilesTypeHandler;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.ToString;
import lombok.experimental.SuperBuilder;

/**
 * 商家数据模型
 *
 * @author xp
 * @data 2023/4/10
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
@TableName(autoResultMap = true)
public class Merchant extends ModifyEntity<Long> {
    /**
     * 主键
     */
    @TableId(type = IdType.AUTO)
    private Long id;

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 商家名称
     */
    private String name;

    /**
     * 商家Logo
     */
    private String logo;

    /**
     * 轮播图列表
     */
    @TableField(typeHandler = FilesTypeHandler.class)
    private List<File> banners;

    /**
     * 联系人
     */
    private String liaison;

    /**
     * 联系电话
     */
    private String mobile;

    /**
     * 营业时间
     */
    private String opening;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 商家评分
     */
    private Double score;

    /**
     * 订单销量
     */
    private Integer sale;

    /**
     * 所属地区
     */
    private Integer region;

    /**
     * 经度
     */
    private Double longitude;

    /**
     * 纬度
     */
    private Double latitude;

    /**
     * 是否推荐
     */
    private Boolean recommend;

    /**
     * 商家状态
     */
    private MerchantStatus status;

    /**
     * 好评数量
     */
    private Integer goodReview;

    /**
     * 距离（米）
     */
    @TableField(exist = false)
    private Integer distance;
}
