package com.chelvc.cloud.vehicle.server.service.impl;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.uc.api.dto.UserDTO;
import com.chelvc.cloud.uc.api.service.UserService;
import com.chelvc.cloud.vehicle.api.dto.CommentDTO;
import com.chelvc.cloud.vehicle.api.param.CommentQueryParam;
import com.chelvc.cloud.vehicle.server.dao.CommentMapper;
import com.chelvc.cloud.vehicle.server.entity.Comment;
import com.chelvc.cloud.vehicle.server.service.CommentService;
import lombok.NonNull;
import org.apache.dubbo.config.annotation.DubboReference;
import org.apache.dubbo.config.annotation.DubboService;
import org.springframework.util.CollectionUtils;

/**
 * 商家评论业务操作实现
 *
 * @author xp
 * @data 2023/3/31
 */
@DubboService(interfaceClass = com.chelvc.cloud.vehicle.api.service.CommentService.class)
public class CommentServiceImpl extends ServiceImpl<CommentMapper, Comment> implements CommentService,
        com.chelvc.cloud.vehicle.api.service.CommentService {
    @DubboReference
    private UserService userService;

    @Override
    public List<CommentDTO> listGoodsComments(@NonNull Long goodsId, @NonNull CommentQueryParam param) {
        // 获取商品评价列表
        List<CommentDTO> comments = this.baseMapper.listGoodsComments(goodsId, param);

        // 加载评价用户信息
        Set<Long> userIds = CollectionUtils.isEmpty(comments) ? Collections.emptySet() :
                comments.stream().map(CommentDTO::getUserId).filter(Objects::nonNull).collect(Collectors.toSet());
        if (!CollectionUtils.isEmpty(userIds)) {
            Map<Long, UserDTO> users = this.userService.listUsers(userIds).stream()
                    .collect(Collectors.toMap(UserDTO::getId, user -> user));
            comments.forEach(comment -> comment.setUser(users.get(comment.getUserId())));
        }
        return comments;
    }
}
