package com.chelvc.cloud.vehicle.server.service.impl;

import java.util.Collection;
import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.api.dto.CouponDTO;
import com.chelvc.cloud.vehicle.api.param.CouponModifyParam;
import com.chelvc.cloud.vehicle.api.param.CouponPagingParam;
import com.chelvc.cloud.vehicle.server.copier.CouponCopier;
import com.chelvc.cloud.vehicle.server.dao.CouponMapper;
import com.chelvc.cloud.vehicle.server.entity.Coupon;
import com.chelvc.cloud.vehicle.server.service.CouponService;
import com.chelvc.framework.base.util.ResourceUtils;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.database.context.DatabaseContextHolder;
import com.chelvc.framework.database.util.PagingUtils;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import org.apache.dubbo.config.annotation.DubboService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 优惠券业务操作实现
 *
 * @author liude
 * @date 2023/8/17
 */
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
@DubboService(interfaceClass = com.chelvc.cloud.vehicle.api.service.CouponService.class)
public class CouponServiceImpl extends ServiceImpl<CouponMapper, Coupon> implements CouponService,
        com.chelvc.cloud.vehicle.api.service.CouponService {
    @Override
    public List<CouponDTO> listUserGoodsActiveCoupons(@NonNull Long userId, Collection<Long> goodsCouponIds) {
        return this.baseMapper.listUserGoodsActiveCoupons(userId, goodsCouponIds);
    }



    @Override
    public Long addCoupon(CouponModifyParam param){
        Coupon coupon = CouponCopier.INSTANCE.copying(param);
        this.save(coupon);
        return coupon.getId();
    }

    @Override
    public void updateCoupon(@NonNull Long id, @NonNull CouponModifyParam param) {
        Coupon coupon = ResourceUtils.required(this.getById(id), "商品优惠卷不存在");
        CouponCopier.INSTANCE.copying(param, coupon);
        this.updateById(coupon);
    }

    @Override
    public void deleteCoupon(@NonNull Long id) {
        ResourceUtils.required(this.getById(id), "商品优惠卷不存在");
        this.baseMapper.deleteById(id);
    }

    @Override
    public Pagination<CouponDTO> getCouponPaging(@NonNull CouponPagingParam param) {
        Page<Coupon> page = this.lambdaQuery()
                .like(StringUtils.nonEmpty(param.getName()), Coupon::getName, param.getName())
                .orderByAsc(Coupon::getStatus).page(PagingUtils.convert(param.getPaging()));
        return PagingUtils.convert(page, CouponCopier.INSTANCE::copying);
    }
}
