package com.chelvc.cloud.vehicle.server.service.impl;

import java.util.Date;
import java.util.Objects;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.api.constant.FavoriteType;
import com.chelvc.cloud.vehicle.server.dao.FavoriteMapper;
import com.chelvc.cloud.vehicle.server.entity.Favorite;
import com.chelvc.cloud.vehicle.server.service.FavoriteService;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.base.util.ResourceUtils;
import lombok.NonNull;
import org.apache.dubbo.config.annotation.DubboService;

/**
 * 用户收藏业务操作实现
 *
 * @author liude
 * @date 2023/7/20
 */
@DubboService(interfaceClass = com.chelvc.cloud.vehicle.api.service.FavoriteService.class)
public class FavoriteServiceImpl extends ServiceImpl<FavoriteMapper, Favorite> implements FavoriteService,
        com.chelvc.cloud.vehicle.api.service.FavoriteService {
    @Override
    public Long addMerchantFavorite(@NonNull Long merchantId) {
        Favorite favorite = Favorite.builder().userId(SessionContextHolder.getId()).type(FavoriteType.MERCHANT)
                .contentId(merchantId).createTime(new Date()).build();
        boolean success = this.baseMapper.createOrIgnore(favorite);
        ResourceUtils.available(success, "收藏信息已存在");
        return favorite.getId();
    }

    @Override
    public void deleteMineFavorite(@NonNull Long id) {
        Favorite favorite = ResourceUtils.required(this.getById(id), "收藏信息不存在");
        ResourceUtils.available(Objects.equals(favorite.getUserId(), SessionContextHolder.getId()), "非法操作");
        this.removeById(id);
    }
}
